@@ -1,6 +1,5 @@
 from django import forms
 from django.contrib import admin
-from django.conf import settings
 
 class ImageUploaderInline(admin.StackedInline):
     template = 'admin/edit_inline/image_uploader.html'
@@ -8,14 +7,14 @@ class ImageUploaderInline(admin.StackedInline):
 
     @property
     def media(self):
-        extra = '' if settings.DEBUG else '.min'
         return forms.Media(
             js = [
-                'admin/js/image-uploader-inline%s.js' % extra
+                'admin/js/image-uploader-modal.js',
+                'admin/js/image-uploader-inline.js',
             ],
             css = {
                 'screen': [
-                    'admin/css/image-uploader-inline%s.css' % extra,
+                    'admin/css/image-uploader-inline.css',
                 ]
             }
         )
